@@ -50,7 +50,8 @@ class Server(object):
     :param cors_allowed_origins: Origin or list of origins that are allowed to
                                  connect to this server. Only the same origin
                                  is allowed by default. Set this argument to
-                                 ``'*'`` to allow all origins.
+                                 ``'*'`` to allow all origins, or to ``[]`` to
+                                 disable CORS handling.
     :param cors_credentials: Whether credentials (cookies, authentication) are
                              allowed in requests to this server. The default
                              is ``True``.
@@ -602,10 +603,13 @@ class Server(object):
 
     def _cors_headers(self, environ):
         """Return the cross-origin-resource-sharing headers."""
+        if self.cors_allowed_origins == []:
+            # special case, CORS handling is completely disabled
+            return []
         headers = []
         allowed_origins = self._cors_allowed_origins(environ)
-        if allowed_origins is None or \
-                ('HTTP_ORIGIN' in environ and environ['HTTP_ORIGIN'] in
+        if 'HTTP_ORIGIN' in environ and \
+                (allowed_origins is None or environ['HTTP_ORIGIN'] in
                  allowed_origins):
             headers = [('Access-Control-Allow-Origin', environ['HTTP_ORIGIN'])]
         if environ['REQUEST_METHOD'] == 'OPTIONS':
