@@ -488,6 +488,47 @@ class TestAsyncServer(unittest.TestCase):
         self.assertIn(('Access-Control-Allow-Methods',
                        'OPTIONS, GET, POST'), headers)
 
+    @mock.patch('importlib.import_module')
+    def test_connect_cors_disabled(self, import_module):
+        a = self.get_async_mock({'REQUEST_METHOD': 'GET', 'QUERY_STRING': '',
+                                 'HTTP_ORIGIN': 'http://foo'})
+        import_module.side_effect = [a]
+        s = asyncio_server.AsyncServer(cors_allowed_origins=[])
+        _run(s.handle_request('request'))
+        headers = a._async['make_response'].call_args[0][1]
+        for header in headers:
+            self.assertFalse(header[0].startswith('Access-Control-'))
+
+    @mock.patch('importlib.import_module')
+    def test_connect_cors_default_no_origin(self, import_module):
+        a = self.get_async_mock({'REQUEST_METHOD': 'GET', 'QUERY_STRING': ''})
+        import_module.side_effect = [a]
+        s = asyncio_server.AsyncServer(cors_allowed_origins=[])
+        _run(s.handle_request('request'))
+        headers = a._async['make_response'].call_args[0][1]
+        for header in headers:
+            self.assertNotEqual(header[0], 'Access-Control-Allow-Origin')
+
+    @mock.patch('importlib.import_module')
+    def test_connect_cors_all_no_origin(self, import_module):
+        a = self.get_async_mock({'REQUEST_METHOD': 'GET', 'QUERY_STRING': ''})
+        import_module.side_effect = [a]
+        s = asyncio_server.AsyncServer(cors_allowed_origins='*')
+        _run(s.handle_request('request'))
+        headers = a._async['make_response'].call_args[0][1]
+        for header in headers:
+            self.assertNotEqual(header[0], 'Access-Control-Allow-Origin')
+
+    @mock.patch('importlib.import_module')
+    def test_connect_cors_disabled_no_origin(self, import_module):
+        a = self.get_async_mock({'REQUEST_METHOD': 'GET', 'QUERY_STRING': ''})
+        import_module.side_effect = [a]
+        s = asyncio_server.AsyncServer(cors_allowed_origins=[])
+        _run(s.handle_request('request'))
+        headers = a._async['make_response'].call_args[0][1]
+        for header in headers:
+            self.assertNotEqual(header[0], 'Access-Control-Allow-Origin')
+
     @mock.patch('importlib.import_module')
     def test_connect_event(self, import_module):
         a = self.get_async_mock()
